summaryrefslogtreecommitdiff
path: root/spec/spec_helper.rb
diff options
context:
space:
mode:
authorAndrew8xx8 <avk@8xx8.ru>2013-03-26 13:13:30 +0400
committerAndrew8xx8 <avk@8xx8.ru>2013-03-26 13:38:42 +0400
commit5949e302431167ecd61dec198e26f6587dbe0955 (patch)
treeb80d07caa595403bf30e689242965e43b18f1654 /spec/spec_helper.rb
parent90db28d6d0a031cad8dc58bc5936e381ce82a764 (diff)
downloadgitlab-ce-5949e302431167ecd61dec198e26f6587dbe0955.tar.gz
Spork support added
Diffstat (limited to 'spec/spec_helper.rb')
-rw-r--r--spec/spec_helper.rb101
1 files changed, 58 insertions, 43 deletions
diff --git a/spec/spec_helper.rb b/spec/spec_helper.rb
index 0f593de854b..03c586f81cf 100644
--- a/spec/spec_helper.rb
+++ b/spec/spec_helper.rb
@@ -1,47 +1,62 @@
-require 'simplecov' unless ENV['CI']
+require 'rubygems'
+require 'spork'
-if ENV['TRAVIS']
- require 'coveralls'
- Coveralls.wear!
-end
+Spork.prefork do
+ require 'simplecov' unless ENV['CI']
+
+ if ENV['TRAVIS']
+ require 'coveralls'
+ Coveralls.wear!
+ end
-# This file is copied to spec/ when you run 'rails generate rspec:install'
-ENV["RAILS_ENV"] ||= 'test'
-require File.expand_path("../../config/environment", __FILE__)
-require 'rspec/rails'
-require 'capybara/rails'
-require 'capybara/rspec'
-require 'webmock/rspec'
-require 'email_spec'
-require 'sidekiq/testing/inline'
-require 'capybara/poltergeist'
-Capybara.javascript_driver = :poltergeist
-Capybara.default_wait_time = 10
-
-# Requires supporting ruby files with custom matchers and macros, etc,
-# in spec/support/ and its subdirectories.
-Dir[Rails.root.join("spec/support/**/*.rb")].each {|f| require f}
-
-WebMock.disable_net_connect!(allow_localhost: true)
-
-RSpec.configure do |config|
- config.mock_with :rspec
-
- config.include LoginHelpers, type: :feature
- config.include LoginHelpers, type: :request
- config.include FactoryGirl::Syntax::Methods
- config.include Devise::TestHelpers, type: :controller
-
- # If you're not using ActiveRecord, or you'd prefer not to run each of your
- # examples within a transaction, remove the following line or assign false
- # instead of true.
- config.use_transactional_fixtures = false
-
- config.before do
- # Use tmp dir for FS manipulations
- temp_repos_path = Rails.root.join('tmp', 'test-git-base-path')
- Gitlab.config.gitlab_shell.stub(repos_path: temp_repos_path)
- FileUtils.rm_rf temp_repos_path
- FileUtils.mkdir_p temp_repos_path
+ # This file is copied to spec/ when you run 'rails generate rspec:install'
+ ENV["RAILS_ENV"] ||= 'test'
+ require File.expand_path("../../config/environment", __FILE__)
+ require 'rspec/rails'
+ require 'capybara/rails'
+ require 'capybara/rspec'
+ require 'webmock/rspec'
+ require 'email_spec'
+ require 'sidekiq/testing/inline'
+ require 'capybara/poltergeist'
+
+ # Loading more in this block will cause your tests to run faster. However,
+
+ # if you change any configuration or code from libraries loaded here, you'll
+ # need to restart spork for it take effect.
+ Capybara.javascript_driver = :poltergeist
+ Capybara.default_wait_time = 10
+
+ # Requires supporting ruby files with custom matchers and macros, etc,
+ # in spec/support/ and its subdirectories.
+ Dir[Rails.root.join("spec/support/**/*.rb")].each {|f| require f}
+
+ WebMock.disable_net_connect!(allow_localhost: true)
+
+ RSpec.configure do |config|
+ config.mock_with :rspec
+
+ config.include LoginHelpers, type: :feature
+ config.include LoginHelpers, type: :request
+ config.include FactoryGirl::Syntax::Methods
+ config.include Devise::TestHelpers, type: :controller
+
+ # If you're not using ActiveRecord, or you'd prefer not to run each of your
+ # examples within a transaction, remove the following line or assign false
+ # instead of true.
+ config.use_transactional_fixtures = false
+
+ config.before do
+ # Use tmp dir for FS manipulations
+ temp_repos_path = Rails.root.join('tmp', 'test-git-base-path')
+ Gitlab.config.gitlab_shell.stub(repos_path: temp_repos_path)
+ FileUtils.rm_rf temp_repos_path
+ FileUtils.mkdir_p temp_repos_path
+ end
end
end
+
+Spork.each_run do
+ # This code will be run each time you run your specs.
+
+end